        public DssClient(Uri uri)
        {
            dssUri = uri;
        }

        public void ConnectToServer(string dssUserName, string dssUserPassword)
        {
            extractionsContext = new ExtractionsContext(dssUri, dssUserName, dssUserPassword) { Options = { AutomaticDecompression = false }, Preferences = { WaitSeconds = 30 } };
            DebugPrintLine("Successfully connect to server.");
        }

        public TickHistoryTimeAndSalesExtractionRequest CreateRequest(IEnumerable<string> symbols, DateTime fromDateTime, DateTime toDateTime)
        {
            var identifierList = InstrumentIdentifierList.Create(symbols.Select(ric => new InstrumentIdentifier
            {
                IdentifierType = IdentifierType.Ric,
                Identifier = ric
            }).ToArray());

            identifierList.UseUserPreferencesForValidationOptions = false;
            identifierList.ValidationOptions = new InstrumentValidationOptions
            {
                AllowHistoricalInstruments = true, //true
                AllowOpenAccessInstruments = true //true
            };

            var extractionRequest = new TickHistoryTimeAndSalesExtractionRequest
            {
                IdentifierList = identifierList,
                ContentFieldNames = { "Trade - Price", "Trade - Volume" },
                Condition = new TickHistoryTimeAndSalesCondition
                {
                    SortBy = TickHistorySort.SingleByRic,
                    MessageTimeStampIn = TickHistoryTimeOptions.GmtUtc,
                    DateRangeTimeZone = "Local Exchange Time Zone",
                    TimeRangeMode = TickHistoryTimeRangeMode.Inclusive,
                    ApplyCorrectionsAndCancellations = true, //true
                    ExtractBy = TickHistoryExtractByMode.Ric,
                    ReportDateRangeType = ReportDateRangeType.Range,
                    QueryStartDate = DateTime.SpecifyKind(fromDateTime, DateTimeKind.Utc),
                    QueryEndDate = DateTime.SpecifyKind(toDateTime, DateTimeKind.Utc)
                }
            };
            return extractionRequest;
        }

        public void ExtractRaw(ExtractionRequestBase request)
        {
            var result = extractionsContext.ExtractRaw(request);

            foreach (string note in result.Notes){
                System.Console.WriteLine(note);
            }
            var streamResponse = extractionsContext.RawExtractionResultOperations.GetReadStream(result);

            var rows = new List<string>();
            using (var gzip = new GZipInputStream(streamResponse.Stream))
            {
                using (var reader = new StreamReader(gzip, Encoding.UTF8))
                {
                    using (System.IO.StreamWriter file = new System.IO.StreamWriter("result.txt"))
                    {
                        string line;
                        while ((line = reader.ReadLine()) != null)
                            file.WriteLine(line);
                    }
                }
            }
        }